Cross-platform process abstraction
Provides a unified interface for discovering and managing processes across macOS, Linux, and Windows.
Structs
- Process
- Represents a system process with relevant information
Enums
- Process
Status - Process status
Functions
- parse_
signal_ name - Parse a signal name to a nix Signal (Unix only)