Module commands

Module commands 

CLI command implementations

Each command is implemented in its own module and follows a consistent pattern:

  • Parse arguments from clap
  • Execute the operation
  • Format and display results

Re-exports

pub use by::ByCommand;
pub use find_in::InCommand;
pub use for_file::ForCommand;
pub use free::FreeCommand;
pub use freeze::FreezeCommand;
pub use info::InfoCommand;
pub use kill::KillCommand;
pub use list::ListCommand;
pub use on::OnCommand;
pub use orphans::OrphansCommand;
pub use ports::PortsCommand;
pub use stop::StopCommand;
pub use stuck::StuckCommand;
pub use thaw::ThawCommand;
pub use tree::TreeCommand;
pub use unstick::UnstickCommand;
pub use watch::WatchCommand;
pub use why::WhyCommand;

Modules

by
proc by - Filter processes by name
find_in
proc in - Filter processes by working directory
for_file
proc for - Find processes by file path
free
proc free - Free ports by killing their processes and verifying availability
freeze
proc freeze - Pause processes with SIGSTOP
info
Info command - Get detailed process information
kill
proc kill - Kill processes
list
proc list - List processes
on
proc on - Port/process lookup
orphans
proc orphans - Find orphaned processes
ports
proc ports - List all listening ports
stop
Stop command - Graceful process termination (SIGTERM)
stuck
proc stuck - Find stuck/hung processes
thaw
proc thaw - Resume frozen processes with SIGCONT
tree
Tree command - Show process tree
unstick
Unstick command - Attempt to recover stuck processes
watch
proc watch - Real-time process monitoring
why
proc why - Explain why a port is busy or trace process ancestry