proc why - Explain why a port is busy or trace process ancestry
Examples: proc why :3000 # Why is port 3000 busy? (ancestry + port context) proc why node # Show ancestry for node processes proc why 1234 # Show ancestry for PID 1234 proc why :3000 –json # JSON output with port context
Structs
- WhyCommand
- Trace why a port is busy or show process ancestry